==> package-sources-1.5.3.zip: package-sources-1.5.3/camel-service/src/test/java/org/ow2/jonas/camel/service/test/CamelServiceTest.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CamelServiceTest.java 20142 2010-08-04 15:12:42Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.camel.service.test;

import java.io.InputStream;

import javax.jms.ConnectionFactory;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.apache.activemq.ActiveMQConnectionFactory;
import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.jms.JmsComponent;
import org.apache.camel.impl.ServiceSupport;
import org.ow2.jonas.camel.service.api.ICamelService;
import org.ow2.jonas.camel.service.impl.CamelService;

/**
 * @author Guillaume Porcher
 */
public class CamelServiceTest extends TestCase {

    /**
     * Camel service instance used by this test.
     */
    private CamelService camelService;

    /**
     * @return the camel service
     */
    private ICamelService getICamelService() {
        return this.camelService;
    }

    /**
     * Create an instance of camelService.
     */
    @Override
    protected void setUp() throws Exception {
        super.setUp();
        this.camelService = new CamelService(null);
        this.camelService.start();
    }

    /**
     * @see junit.framework.TestCase#tearDown()
     */
    @Override
    protected void tearDown() throws Exception {
        super.tearDown();
        this.camelService.stop();
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#getContextNames()}.
     * 
     * @throws Exception
     */
    public void testGetContextNames() throws Exception {
        // Create service
        final ICamelService camelService = this.getICamelService();

        // Check context names is empty
        Assert.assertNotNull(camelService.getContextNames());
        Assert.assertTrue(camelService.getContextNames().isEmpty());

        // start new context
        final String contextName = camelService.startNewContext();

        // check context names contains new context
        Assert.assertEquals(1, camelService.getContextNames().size());
        Assert.assertEquals(contextName, camelService.getContextNames().get(0));

        // stop context
        camelService.stop(contextName);

        // context is removed
        Assert.assertTrue(camelService.getContextNames().isEmpty());

    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#getCamelContext(java.lang.String)}
     * .
     */
    public void testGetCamelContext() throws Exception {
        // Create service
        final ICamelService camelService = this.getICamelService();

        // Check context names is empty
        Assert.assertNotNull(camelService.getContextNames());
        Assert.assertTrue(camelService.getContextNames().isEmpty());

        // start new context
        final String contextName = camelService.startNewContext();

        // get camelContext:
        final CamelContext camelContext = camelService.getCamelContext(contextName);

        Assert.assertNotNull(camelContext);
        Assert.assertEquals(contextName, camelContext.getName());

        final CamelContext invalidCamelContext = camelService.getCamelContext("invalid");
        Assert.assertNull(invalidCamelContext);
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#startNewContext()}.
     * 
     * @throws Exception
     */
    public void testStartNewContext() throws Exception {
        // Create service
        final ICamelService camelService = this.getICamelService();

        // start new context
        final String contextName = camelService.startNewContext();

        Assert.assertNotNull(contextName);

        // get camelContext:
        final CamelContext camelContext = camelService.getCamelContext(contextName);

        Assert.assertNotNull(camelContext);
        Assert.assertTrue(((ServiceSupport) camelContext).isStarted());

    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#startAndGetNewContext()}
     * .
     * 
     * @throws Exception
     */
    public void testStartAndGetNewContext() throws Exception {
        // Create service
        final ICamelService camelService = this.getICamelService();

        // start new context
        final CamelContext camelContext = camelService.startAndGetNewContext();

        Assert.assertNotNull(camelContext);

        // get camelContext:
        Assert.assertEquals(camelContext, camelService.getCamelContext(camelContext.getName()));

    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#stop(java.lang.String)}
     * .
     * 
     * @throws Exception
     */
    public void testStop() throws Exception {
        // Create service
        final ICamelService camelService = this.getICamelService();

        // start new context
        final String contextName = camelService.startNewContext();

        Assert.assertNotNull(contextName);

        // get camelContext:
        final CamelContext camelContext = camelService.getCamelContext(contextName);

        Assert.assertNotNull(camelContext);
        Assert.assertTrue(((ServiceSupport) camelContext).isStarted());

        // stop context
        camelService.stop(contextName);
        Assert.assertTrue(((ServiceSupport) camelContext).isStopped());

    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#addRoutes(org.apache.camel.builder.RouteBuilder, java.lang.String)}
     * .
     * 
     * @throws Exception
     */
    public void testAddRoutes() throws Exception {
        // Create service
        final ICamelService camelService = this.getICamelService();

        // start new context
        final String contextName = camelService.startNewContext();

        Assert.assertNotNull(contextName);

        // get camelContext:
        final CamelContext camelContext = camelService.getCamelContext(contextName);

        Assert.assertTrue(camelContext.getRoutes().isEmpty());

        // add route
        camelService.addRoutes(new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                this.from("direct:a").to("direct:b");
                this.from("direct:c").to("direct:d");
            }
        }, contextName);

        // check routes are added
        Assert.assertEquals(2, camelContext.getRoutes().size());
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#getRoutes(java.lang.String)}
     * .
     * 
     * @throws Exception
     */
    public void testGetRouteDefinitions() throws Exception {
        // Create service
        final ICamelService camelService = this.getICamelService();

        // start new context
        final String contextName = camelService.startNewContext();

        Assert.assertNotNull(contextName);

        // get camelContext:
        Assert.assertTrue(camelService.getRouteDefinitions(contextName).isEmpty());

        // add route
        camelService.addRoutes(new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                this.from("direct:a").to("direct:b");
                this.from("direct:c").to("direct:d");
            }
        }, contextName);

        // check routes are added
        Assert.assertEquals(2, camelService.getRouteDefinitions(contextName).size());

    }

    // /**
    // * Test method for {@link
    // org.ow2.jonas.camel.service.api.ICamelService#getProducerTemplate(java.lang.String)}.
    // */
    // public void testGetProducerTemplate() {
    // Assert.fail("Not yet implemented");
    // }
    //
    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#addRegistry(java.io.InputStream, java.lang.String)}
     * .
     * 
     * @throws Exception
     */
    public void testAddRegistry() throws Exception {
        InputStream stream = Thread.currentThread().getContextClassLoader().getResourceAsStream("registry.xml");
        // Create service
        final ICamelService camelService = this.getICamelService();

        // start new context
        final String contextName = camelService.startNewContext();

        Assert.assertNotNull(contextName);

        CamelContext ctxt = camelService.getCamelContext(contextName);

        ConnectionFactory connectionFactory = new ActiveMQConnectionFactory("vm://localhost?broker.persistent=false");
        ctxt.addComponent("test-jms", JmsComponent.jmsComponentAutoAcknowledge(connectionFactory));

        camelService.addRegistry(stream, contextName);

        Endpoint endpoint = (Endpoint) ctxt.getRegistry().lookup("queue");

        Assert.assertNotNull(endpoint);

        Assert.assertEquals("test-jms://queue:sampleQueue", endpoint.getEndpointUri());

    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#removeRegistry(java.io.InputStream, java.lang.String)}
     * .
     * 
     * @throws Exception
     */
    public void testRemoveRegistry() throws Exception {
        InputStream stream = Thread.currentThread().getContextClassLoader().getResourceAsStream("registry.xml");
        // Create service
        final ICamelService camelService = this.getICamelService();

        // start new context
        final String contextName = camelService.startNewContext();

        Assert.assertNotNull(contextName);

        CamelContext ctxt = camelService.getCamelContext(contextName);

        ConnectionFactory connectionFactory = new ActiveMQConnectionFactory("vm://localhost?broker.persistent=false");
        ctxt.addComponent("test-jms", JmsComponent.jmsComponentAutoAcknowledge(connectionFactory));

        camelService.addRegistry(stream, contextName);

        stream = Thread.currentThread().getContextClassLoader().getResourceAsStream("registry.xml");

        camelService.removeRegistry(stream, contextName);

        Object endpoint = ctxt.getRegistry().lookup("queue");

        Assert.assertNull(endpoint);

    }

    // /**
    // * Test method for {@link
    // org.ow2.jonas.camel.service.api.ICamelService#addComponent(java.lang.String,
    // org.apache.camel.Component, java.lang.String)}.
    // */
    // public void testAddComponent() {
    // Assert.fail("Not yet implemented");
    // }

}

==> package-sources-1.5.4.zip: package-sources-1.5.4/camel-service/src/test/java/org/ow2/jonas/camel/service/test/CamelServiceTest.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CamelServiceTest.java 20423 2010-10-05 06:47:16Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.camel.service.test;

import java.io.InputStream;

import javax.jms.ConnectionFactory;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.apache.activemq.ActiveMQConnectionFactory;
import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.jms.JmsComponent;
import org.apache.camel.impl.ServiceSupport;
import org.ow2.jonas.camel.service.api.ICamelService;
import org.ow2.jonas.camel.service.impl.CamelService;

/**
 * @author Guillaume Porcher
 */
public class CamelServiceTest extends TestCase {

    /**
     * Camel service instance used by this test.
     */
    private CamelService camelService;

    /**
     * Create an instance of this.camelService.
     */
    @Override
    protected void setUp() throws Exception {
        super.setUp();
        this.camelService = new CamelService(null);
        this.camelService.start();
    }

    /**
     * @see junit.framework.TestCase#tearDown()
     */
    @Override
    protected void tearDown() throws Exception {
        super.tearDown();
        this.camelService.stop();
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#getContextNames()}.
     * 
     * @throws Exception
     */
    public void testGetContextNames() throws Exception {
        // Check context names is empty
        Assert.assertNotNull(this.camelService.getContextNames());
        Assert.assertTrue(this.camelService.getContextNames().isEmpty());

        // start new context
        final String contextName = this.camelService.startNewContext();

        // check context names contains new context
        Assert.assertEquals(1, this.camelService.getContextNames().size());
        Assert.assertEquals(contextName, this.camelService.getContextNames().get(0));

        // stop context
        this.camelService.stop(contextName);

        // context is removed
        Assert.assertTrue(this.camelService.getContextNames().isEmpty());
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#getCamelContext(java.lang.String)}
     * .
     */
    public void testGetCamelContext() throws Exception {
        // Check context names is empty
        Assert.assertNotNull(this.camelService.getContextNames());
        Assert.assertTrue(this.camelService.getContextNames().isEmpty());

        // start new context
        final String contextName = this.camelService.startNewContext();

        // get camelContext:
        final CamelContext camelContext = this.camelService.getCamelContext(contextName);

        Assert.assertNotNull(camelContext);
        Assert.assertEquals(contextName, camelContext.getName());

        final CamelContext invalidCamelContext = this.camelService.getCamelContext("invalid");
        Assert.assertNull(invalidCamelContext);
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#startNewContext()}.
     * 
     * @throws Exception
     */
    public void testStartNewContext() throws Exception {
        // start new context
        final String contextName = this.camelService.startNewContext();

        Assert.assertNotNull(contextName);

        // get camelContext:
        final CamelContext camelContext = this.camelService.getCamelContext(contextName);

        Assert.assertNotNull(camelContext);
        Assert.assertTrue(((ServiceSupport) camelContext).isStarted());
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#startAndGetNewContext()}
     * .
     * 
     * @throws Exception
     */
    public void testStartAndGetNewContext() throws Exception {
        // start new context
        final CamelContext camelContext = this.camelService.startAndGetNewContext();

        Assert.assertNotNull(camelContext);

        // get camelContext:
        Assert.assertEquals(camelContext, this.camelService.getCamelContext(camelContext.getName()));
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#stop(java.lang.String)}
     * .
     * 
     * @throws Exception
     */
    public void testStop() throws Exception {
        // start new context
        final String contextName = this.camelService.startNewContext();

        Assert.assertNotNull(contextName);

        // get camelContext:
        final CamelContext camelContext = this.camelService.getCamelContext(contextName);

        Assert.assertNotNull(camelContext);
        Assert.assertTrue(((ServiceSupport) camelContext).isStarted());

        // stop context
        this.camelService.stop(contextName);
        Assert.assertTrue(((ServiceSupport) camelContext).isStopped());
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#addRoutes(org.apache.camel.builder.RouteBuilder, java.lang.String)}
     * .
     * 
     * @throws Exception
     */
    public void testAddRoutes() throws Exception {
        // start new context
        final String contextName = this.camelService.startNewContext();

        Assert.assertNotNull(contextName);

        // get camelContext
        final CamelContext camelContext = this.camelService.getCamelContext(contextName);

        Assert.assertTrue(camelContext.getRoutes().isEmpty());

        // add route
        this.camelService.addRoutes(new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                this.from("direct:a").to("direct:b");
                this.from("direct:c").to("direct:d");
            }
        }, contextName);

        // check routes are added
        Assert.assertEquals(2, camelContext.getRoutes().size());
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#getRoutes(java.lang.String)}
     * .
     * 
     * @throws Exception
     */
    public void testGetRouteDefinitions() throws Exception {
        // start new context
        final String contextName = this.camelService.startNewContext();

        Assert.assertNotNull(contextName);

        // get routeDefinitions
        Assert.assertTrue(this.camelService.getRouteDefinitions(contextName).isEmpty());

        // add route
        this.camelService.addRoutes(new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                this.from("direct:a").to("direct:b");
                this.from("direct:c").to("direct:d");
            }
        }, contextName);

        // check routes are added
        Assert.assertEquals(2, this.camelService.getRouteDefinitions(contextName).size());
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#getProducerTemplate(java.lang.String)}.
     */
     /*
    public void testGetProducerTemplate() {
        Assert.fail("Not yet implemented");
    }
     */

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#addRegistry(java.io.InputStream, java.lang.String)}
     * .
     * 
     * @throws Exception
     */
    public void testAddRegistry() throws Exception {
        InputStream stream = Thread.currentThread().getContextClassLoader().getResourceAsStream("registry.xml");

        // start new context
        final String contextName = this.camelService.startNewContext();

        Assert.assertNotNull(contextName);

        CamelContext ctxt = this.camelService.getCamelContext(contextName);

        ConnectionFactory connectionFactory = new ActiveMQConnectionFactory("vm://localhost?broker.persistent=false");
        ctxt.addComponent("test-jms", JmsComponent.jmsComponentAutoAcknowledge(connectionFactory));

        this.camelService.addRegistry(stream, contextName);

        Endpoint endpoint = (Endpoint) ctxt.getRegistry().lookup("queue");

        Assert.assertNotNull(endpoint);

        Assert.assertEquals("test-jms://queue:sampleQueue", endpoint.getEndpointUri());
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#removeRegistry(java.io.InputStream, java.lang.String)}
     * .
     * 
     * @throws Exception
     */
    public void testRemoveRegistry() throws Exception {
        InputStream stream = Thread.currentThread().getContextClassLoader().getResourceAsStream("registry.xml");

        // start new context
        final String contextName = this.camelService.startNewContext();

        Assert.assertNotNull(contextName);

        CamelContext ctxt = this.camelService.getCamelContext(contextName);

        ConnectionFactory connectionFactory = new ActiveMQConnectionFactory("vm://localhost?broker.persistent=false");
        ctxt.addComponent("test-jms", JmsComponent.jmsComponentAutoAcknowledge(connectionFactory));

        this.camelService.addRegistry(stream, contextName);

        stream = Thread.currentThread().getContextClassLoader().getResourceAsStream("registry.xml");

        this.camelService.removeRegistry(stream, contextName);

        Object endpoint = ctxt.getRegistry().lookup("queue");

        Assert.assertNull(endpoint);
    }

    /**
     * Test method for
     * {@link org.ow2.jonas.camel.service.api.ICamelService#addComponent(java.lang.String, org.apache.camel.Component, java.lang.String)}.
     */
     /*
    public void testAddComponent() {
        Assert.fail("Not yet implemented");
    }
     */

}
